(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     10386,        421]*)
(*NotebookOutlinePosition[     14021,        538]*)
(*  CellTagsIndexPosition[     13852,        528]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " ",
  StyleBox["CalcCenter",
    FontSlant->"Italic"]
}], "Title"],

Cell[CellGroupData[{

Cell[TextData[{
  "About ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " ",
  StyleBox["CalcCenter",
    FontSlant->"Italic"]
}], "Section",
  CellTags->"b:0.0"],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " ",
  StyleBox["CalcCenter",
    FontSlant->"Italic"],
  " 3 combines an innovative interface with key features from ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " ",
  StyleBox["Professional",
    FontSlant->"Italic"],
  "'s industry-leading algebraic solutions, number crunching, data analysis, \
statistics, plotting, technical report writing, and sophisticated calculation \
management.\n\nFor more information on ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " ",
  StyleBox["CalcCenter",
    FontSlant->"Italic"],
  " go to ",
  ButtonBox["http://www.wolfram.com/products/calccenter/",
    ButtonData:>{
      URL[ "http://www.wolfram.com/products/calccenter/"], None},
    ButtonStyle->"Hyperlink"],
  "\n\nThis add-on provides compatibility support to ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " users to allow notebooks created in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " ",
  StyleBox["CalcCenter",
    FontSlant->"Italic"],
  " to be used without change."
}], "Text",
  CellTags->{"b:0.0", "i:1"}]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Using the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " CalcCenter package"
}], "Section",
  CellTags->"b:0.1"],

Cell["Start the emulation package using the command", "Text",
  CellTags->"b:0.1"],

Cell[BoxData[
    \(<< CalcCenter`\)], "Input",
  CellTags->"b:0.1"],

Cell[TextData[{
  "After this, most ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " ",
  StyleBox["CalcCenter",
    FontSlant->"Italic"],
  " documents can be evaluated without change. For example, ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " ",
  StyleBox["CalcCenter",
    FontSlant->"Italic"],
  " has a command SeriesExpand. This is similar to the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " command Series except that it does not produce an order term. Once the \
emulation package has been loaded, you can get usage help on this command"
}], "Text",
  CellTags->"b:0.1"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?SeriesExpand\)\)], "Input",
  CellTags->"b:0.1"],

Cell[BoxData[
    \("SeriesExpand[f, {x, x0, n}] generates a power series expansion for f \
about the point x = x0 to order (x - x0)^n."\)], "Print",
  CellTags->"b:0.1"]
}, Open  ]],

Cell["And use it\[Ellipsis]", "Text",
  CellTags->"b:0.1"],

Cell[CellGroupData[{

Cell[BoxData[
    \(SeriesExpand[Sin[x], {x, 0, 10}]\)], "Input",
  CellTags->"b:0.1"],

Cell[BoxData[
    \(x - x\^3\/6 + x\^5\/120 - x\^7\/5040 + x\^9\/362880\)], "Output",
  CellTags->"b:0.1"]
}, Open  ]],

Cell[TextData[{
  "For documentation on additional functionality provided by ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " ",
  StyleBox["CalcCenter",
    FontSlant->"Italic"],
  ", see ",
  ButtonBox["http://documents.wolfram.com/calccenter/",
    ButtonData:>{
      URL[ "http://documents.wolfram.com/calccenter/"], None},
    ButtonStyle->"Hyperlink"]
}], "Text",
  CellTags->"b:0.1"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Incompatibilities: Numerical computations", "Section",
  CellTags->"b:0.2"],

Cell[TextData[{
  "A key difference between ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " ",
  StyleBox["Professional",
    FontSlant->"Italic"],
  " and ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " ",
  StyleBox["CalcCenter",
    FontSlant->"Italic"],
  " is that ",
  StyleBox["CalcCenter",
    FontSlant->"Italic"],
  " performs all numerical computations to machine precision. It does not \
support integer arithmetic. For example the following input to ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " ",
  StyleBox["CalcCenter",
    FontSlant->"Italic"],
  "..."
}], "Text",
  CellTags->"b:0.2"],

Cell[BoxData[
    \(\@2\)], "Input",
  CellTags->"b:0.2"],

Cell["...would return...", "Text",
  CellTags->"b:0.2"],

Cell[BoxData[
    \(1.4142135623730951`\)], "Output",
  CellTags->"b:0.2"],

Cell[TextData[{
  "...while ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " ",
  StyleBox["Professional",
    FontSlant->"Italic"],
  " returns..."
}], "Text",
  CellTags->"b:0.2"],

Cell[BoxData[
    \(\@2\)], "Output",
  CellTags->"b:0.2"],

Cell[TextData[{
  "The emulator package does not attempt to change this behavior in ",
  StyleBox["Mathematica,",
    FontSlant->"Italic"],
  " since integer arithmetic and high-precision arithmetic are powerful \
additional features.\n\nYou can edit the original ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " ",
  StyleBox["CalcCenter",
    FontSlant->"Italic"],
  " input to use the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " command N to force the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " ",
  StyleBox["CalcCenter",
    FontSlant->"Italic"],
  " behavior.\ne.g. the input could be changed to..."
}], "Text",
  CellTags->"b:0.2"],

Cell[BoxData[
    \(N[\@2]\)], "Input",
  CellTags->"b:0.2"],

Cell[TextData[{
  "...to achieve the same output as ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " ",
  StyleBox["CalcCenter",
    FontSlant->"Italic"],
  " would return. You may find prefix or postfix notation more convenient. \
The following inputs are equivalent:"
}], "Text",
  CellTags->"b:0.2"],

Cell[BoxData[
    \(N@\(\@2\)\)], "Input",
  CellTags->"b:0.2"],

Cell[BoxData[
    \(\@2 // N\)], "Input",
  CellTags->"b:0.2"],

Cell[TextData[{
  "You can set ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to have every result returned as a numerical value. This will give you \
complete emulation of the ",
  StyleBox["CalcCenter",
    FontSlant->"Italic"],
  " environment, but you will not be able to use high precision arithmetic or \
integer arithmetic. To do this evaluate the following input:"
}], "Text",
  CellTags->"b:0.2"],

Cell[BoxData[
    \($Post = N\)], "Input",
  CellTags->"b:0.2"],

Cell[TextData[{
  "You can return ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s default numerical model by evaluating:"
}], "Text",
  CellTags->"b:0.2"],

Cell[BoxData[
    \($Post =. \)], "Input",
  CellTags->"b:0.2"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Incompatibilities: Output formatting", "Section",
  CellTags->"b:0.3"],

Cell[TextData[{
  "There are some differences in output formatting between ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " and ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " ",
  StyleBox["CalcCenter",
    FontSlant->"Italic"],
  ". In most cases these are exactly equivalent outputs. E.g a matrix will \
display as a list of lists by default in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ":"
}], "Text",
  CellTags->"b:0.3"],

Cell[BoxData[
    \({{1, 2}, {3, 4}}\)], "Input",
  CellTags->"b:0.3"],

Cell[TextData[{
  "While in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " ",
  StyleBox["CalcCenter",
    FontSlant->"Italic"],
  ", this is displayed in 2-dimensional form..."
}], "Text",
  CellTags->"b:0.3"],

Cell[BoxData[
    RowBox[{"(", GridBox[{
          {"1", "2"},
          {"3", "4"}
          }], ")"}]], "Input",
  CellTags->"b:0.3"],

Cell[TextData[{
  "The emulator does not change the default ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " notation.\n\nThe most significant issue is the display of numerical \
values. Because ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " ",
  StyleBox["CalcCenter",
    FontSlant->"Italic"],
  " is not designed to perform integer arithmetic, it does not distinguish \
between the display of integers and reals which are approximately integer. \
For example, the input..."
}], "Text",
  CellTags->"b:0.3"],

Cell[BoxData[
    \({1, 1.0}\)], "Input",
  CellTags->"b:0.3"],

Cell["...will display as...", "Text",
  CellTags->"b:0.3"],

Cell[BoxData[
    \({1, 1}\)], "Output",
  CellTags->"b:0.3"],

Cell[TextData[{
  "...in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " ",
  StyleBox["CalcCenter",
    FontSlant->"Italic"],
  ", but in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " as..."
}], "Text",
  CellTags->"b:0.3"],

Cell[BoxData[
    \({1, 1. }\)], "Output",
  CellTags->"b:0.3"]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"5.0 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 926}},
WindowSize->{848, 667},
WindowMargins->{{62, Automatic}, {Automatic, 0}},
ShowSelection->True,
TaggingRules:>{"NextIndexingNumber" -> 2, "IndexEntries" -> {{"i:1", \
"CalcCenter"}}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "b:0.0"->{
    Cell[1938, 63, 172, 8, 73, "Section",
      CellTags->"b:0.0"],
    Cell[2113, 73, 1135, 36, 128, "Text",
      CellTags->{"b:0.0", "i:1"}]},
  "i:1"->{
    Cell[2113, 73, 1135, 36, 128, "Text",
      CellTags->{"b:0.0", "i:1"}]},
  "b:0.1"->{
    Cell[3285, 114, 143, 6, 73, "Section",
      CellTags->"b:0.1"],
    Cell[3431, 122, 82, 1, 33, "Text",
      CellTags->"b:0.1"],
    Cell[3516, 125, 68, 2, 30, "Input",
      CellTags->"b:0.1"],
    Cell[3587, 129, 616, 19, 71, "Text",
      CellTags->"b:0.1"],
    Cell[4228, 152, 71, 2, 30, "Input",
      CellTags->"b:0.1"],
    Cell[4302, 156, 170, 3, 44, "Print",
      CellTags->"b:0.1"],
    Cell[4487, 162, 58, 1, 33, "Text",
      CellTags->"b:0.1"],
    Cell[4570, 167, 86, 2, 30, "Input",
      CellTags->"b:0.1"],
    Cell[4659, 171, 106, 2, 45, "Output",
      CellTags->"b:0.1"],
    Cell[4780, 176, 401, 13, 33, "Text",
      CellTags->"b:0.1"]},
  "b:0.2"->{
    Cell[5218, 194, 81, 1, 73, "Section",
      CellTags->"b:0.2"],
    Cell[5302, 197, 638, 25, 52, "Text",
      CellTags->"b:0.2"],
    Cell[5943, 224, 57, 2, 32, "Input",
      CellTags->"b:0.2"],
    Cell[6003, 228, 55, 1, 33, "Text",
      CellTags->"b:0.2"],
    Cell[6061, 231, 74, 2, 29, "Output",
      CellTags->"b:0.2"],
    Cell[6138, 235, 191, 9, 33, "Text",
      CellTags->"b:0.2"],
    Cell[6332, 246, 58, 2, 30, "Output",
      CellTags->"b:0.2"],
    Cell[6393, 250, 679, 22, 109, "Text",
      CellTags->"b:0.2"],
    Cell[7075, 274, 60, 2, 33, "Input",
      CellTags->"b:0.2"],
    Cell[7138, 278, 312, 10, 52, "Text",
      CellTags->"b:0.2"],
    Cell[7453, 290, 63, 2, 32, "Input",
      CellTags->"b:0.2"],
    Cell[7519, 294, 62, 2, 32, "Input",
      CellTags->"b:0.2"],
    Cell[7584, 298, 417, 11, 52, "Text",
      CellTags->"b:0.2"],
    Cell[8004, 311, 63, 2, 30, "Input",
      CellTags->"b:0.2"],
    Cell[8070, 315, 167, 6, 33, "Text",
      CellTags->"b:0.2"],
    Cell[8240, 323, 63, 2, 30, "Input",
      CellTags->"b:0.2"]},
  "b:0.3"->{
    Cell[8340, 330, 76, 1, 73, "Section",
      CellTags->"b:0.3"],
    Cell[8419, 333, 462, 16, 52, "Text",
      CellTags->"b:0.3"],
    Cell[8884, 351, 70, 2, 30, "Input",
      CellTags->"b:0.3"],
    Cell[8957, 355, 222, 9, 33, "Text",
      CellTags->"b:0.3"],
    Cell[9182, 366, 135, 5, 41, "Input",
      CellTags->"b:0.3"],
    Cell[9320, 373, 531, 15, 90, "Text",
      CellTags->"b:0.3"],
    Cell[9854, 390, 62, 2, 30, "Input",
      CellTags->"b:0.3"],
    Cell[9919, 394, 58, 1, 33, "Text",
      CellTags->"b:0.3"],
    Cell[9980, 397, 61, 2, 29, "Output",
      CellTags->"b:0.3"],
    Cell[10044, 401, 248, 12, 33, "Text",
      CellTags->"b:0.3"],
    Cell[10295, 415, 63, 2, 29, "Output",
      CellTags->"b:0.3"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"b:0.0", 11085, 439},
  {"i:1", 11242, 444},
  {"b:0.1", 11333, 447},
  {"b:0.2", 12013, 468},
  {"b:0.3", 13091, 501}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 137, 6, 95, "Title"],

Cell[CellGroupData[{
Cell[1938, 63, 172, 8, 73, "Section",
  CellTags->"b:0.0"],
Cell[2113, 73, 1135, 36, 128, "Text",
  CellTags->{"b:0.0", "i:1"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[3285, 114, 143, 6, 73, "Section",
  CellTags->"b:0.1"],
Cell[3431, 122, 82, 1, 33, "Text",
  CellTags->"b:0.1"],
Cell[3516, 125, 68, 2, 30, "Input",
  CellTags->"b:0.1"],
Cell[3587, 129, 616, 19, 71, "Text",
  CellTags->"b:0.1"],

Cell[CellGroupData[{
Cell[4228, 152, 71, 2, 30, "Input",
  CellTags->"b:0.1"],
Cell[4302, 156, 170, 3, 44, "Print",
  CellTags->"b:0.1"]
}, Open  ]],
Cell[4487, 162, 58, 1, 33, "Text",
  CellTags->"b:0.1"],

Cell[CellGroupData[{
Cell[4570, 167, 86, 2, 30, "Input",
  CellTags->"b:0.1"],
Cell[4659, 171, 106, 2, 45, "Output",
  CellTags->"b:0.1"]
}, Open  ]],
Cell[4780, 176, 401, 13, 33, "Text",
  CellTags->"b:0.1"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5218, 194, 81, 1, 73, "Section",
  CellTags->"b:0.2"],
Cell[5302, 197, 638, 25, 52, "Text",
  CellTags->"b:0.2"],
Cell[5943, 224, 57, 2, 32, "Input",
  CellTags->"b:0.2"],
Cell[6003, 228, 55, 1, 33, "Text",
  CellTags->"b:0.2"],
Cell[6061, 231, 74, 2, 29, "Output",
  CellTags->"b:0.2"],
Cell[6138, 235, 191, 9, 33, "Text",
  CellTags->"b:0.2"],
Cell[6332, 246, 58, 2, 30, "Output",
  CellTags->"b:0.2"],
Cell[6393, 250, 679, 22, 109, "Text",
  CellTags->"b:0.2"],
Cell[7075, 274, 60, 2, 33, "Input",
  CellTags->"b:0.2"],
Cell[7138, 278, 312, 10, 52, "Text",
  CellTags->"b:0.2"],
Cell[7453, 290, 63, 2, 32, "Input",
  CellTags->"b:0.2"],
Cell[7519, 294, 62, 2, 32, "Input",
  CellTags->"b:0.2"],
Cell[7584, 298, 417, 11, 52, "Text",
  CellTags->"b:0.2"],
Cell[8004, 311, 63, 2, 30, "Input",
  CellTags->"b:0.2"],
Cell[8070, 315, 167, 6, 33, "Text",
  CellTags->"b:0.2"],
Cell[8240, 323, 63, 2, 30, "Input",
  CellTags->"b:0.2"]
}, Open  ]],

Cell[CellGroupData[{
Cell[8340, 330, 76, 1, 73, "Section",
  CellTags->"b:0.3"],
Cell[8419, 333, 462, 16, 52, "Text",
  CellTags->"b:0.3"],
Cell[8884, 351, 70, 2, 30, "Input",
  CellTags->"b:0.3"],
Cell[8957, 355, 222, 9, 33, "Text",
  CellTags->"b:0.3"],
Cell[9182, 366, 135, 5, 41, "Input",
  CellTags->"b:0.3"],
Cell[9320, 373, 531, 15, 90, "Text",
  CellTags->"b:0.3"],
Cell[9854, 390, 62, 2, 30, "Input",
  CellTags->"b:0.3"],
Cell[9919, 394, 58, 1, 33, "Text",
  CellTags->"b:0.3"],
Cell[9980, 397, 61, 2, 29, "Output",
  CellTags->"b:0.3"],
Cell[10044, 401, 248, 12, 33, "Text",
  CellTags->"b:0.3"],
Cell[10295, 415, 63, 2, 29, "Output",
  CellTags->"b:0.3"]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

